// Copyright © 2019 The Knative Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package route

import (
	"github.com/spf13/cobra"

	"knative.dev/client/pkg/kn/commands"
)

func NewRouteCommand(p *commands.KnParams) *cobra.Command {
	routeCmd := &cobra.Command{
		Use:     "route",
		Short:   "List and describe service routes (alias: routes)",
		Aliases: []string{"routes"},
	}
	routeCmd.AddCommand(NewRouteListCommand(p))
	routeCmd.AddCommand(NewRouteDescribeCommand(p))
	return routeCmd
}
